import 'package:logger/logger.dart';
import 'inject.dart';

initLogger(bool enableLogger) => put<Logger>(
      () => Logger(
          printer: PrettyPrinter(
            methodCount: 0,
            errorMethodCount: 12,
            lineLength: 77,
            colors: true,
            printTime: false,
            noBoxingByDefault: false,
          ),
          level: enableLogger ? Logger.level : Level.nothing),
    );

final Logger _logger = get<Logger>();

verbose(dynamic message, [dynamic error, StackTrace? stackTrace]) =>
    _logger.v(message, error, stackTrace);

debug(dynamic message, [dynamic error, StackTrace? stackTrace]) =>
    _logger.d(message, error, stackTrace);

info(dynamic message, [dynamic error, StackTrace? stackTrace]) =>
    _logger.i(message, error, stackTrace);

warning(dynamic message, [dynamic error, StackTrace? stackTrace]) =>
    _logger.w(message, error, stackTrace);

error(dynamic message, [dynamic error, StackTrace? stackTrace]) =>
    _logger.e(message, error, stackTrace);

errorWithStack(Object error, StackTrace stackTrace) =>
    _logger.e(error.toString(), error, stackTrace);

wtf(dynamic message, [dynamic error, StackTrace? stackTrace]) =>
    _logger.wtf(message, error, stackTrace);
